@@ -4,6 +4,8 @@ pub mod alias_dto;
 pub use self::alias_dto::AliasDto;
 pub mod alias_projection;
 pub use self::alias_projection::AliasProjection;
+pub mod attachment_entity;
+pub use self::attachment_entity::AttachmentEntity;
 pub mod attachment_meta_data;
 pub use self::attachment_meta_data::AttachmentMetaData;
 pub mod basic_auth_options;
@@ -98,6 +100,8 @@ pub mod organization_inbox_projection;
 pub use self::organization_inbox_projection::OrganizationInboxProjection;
 pub mod page_alias;
 pub use self::page_alias::PageAlias;
+pub mod page_attachment_entity;
+pub use self::page_attachment_entity::PageAttachmentEntity;
 pub mod page_contact_projection;
 pub use self::page_contact_projection::PageContactProjection;
 pub mod page_email_preview;
